@@ -34,7 +34,7 @@ sub ContentType
   {
     my $type = shift;
     $s->{_content_type} = $type;
-    $s->SetHeader('content-type' => $type);
+    $s->context->r->content_type( $type );
   }
   else
   {
